@@ -1,14 +1,13 @@
 from typing import List, Optional, TYPE_CHECKING, Union
 
-from mstrio import config
 from mstrio.access_and_security.security_filter import (AttributeRef, ObjectInformation,
                                                         Qualification)
-from mstrio.api import changesets, objects, security_filters
+from mstrio.api import changesets, security_filters
 from mstrio.api.security_filters import ShowExpressionAs, UpdateOperator
-from mstrio.browsing import list_objects
+from mstrio.object_management import full_search
 from mstrio.users_and_groups import User, UserGroup
 from mstrio.utils import helper
-from mstrio.utils.entity import Entity, ObjectSubTypes, ObjectTypes
+from mstrio.utils.entity import Entity, ObjectSubTypes, ObjectTypes, DeleteMixin
 
 if TYPE_CHECKING:
     from mstrio.connection import Connection
@@ -16,9 +15,15 @@ if TYPE_CHECKING:
 
 
 def list_security_filters(connection: "Connection", to_dictionary: bool = False,
-                          limit: Optional[int] = None,
+                          limit: Optional[int] = None, user: Optional[Union[str, "User"]] = None,
+                          user_group: Optional[Union[str, "UserGroup"]] = None,
                           **filters) -> Union[List["SecurityFilter"], List[dict]]:
-    """Get list of security filter objects or security filter dicts.
+    """Get list of security filter objects or security filter dicts for the
+    project specified in the connection object. It can be filtered by user or
+    user group.
+
+    Note: It is not possible to provide both `user` and `user_group` parameter.
+        When both arguments are provided error is raised.
 
     Args:
         connection: MicroStrategy connection object returned by
@@ -27,6 +32,10 @@ def list_security_filters(connection: "Connection", to_dictionary: bool = False,
             `SecurityFilter` objects.
         limit: limit the number of elements returned. If `None` (default), all
             objects are returned.
+        user (str or object, optional): Id of user or `User` object used to
+            filter security filters
+        user_group (str or object, optional): Id of user group or `UserGroup`
+            object used to filter security filters
         **filters: Available filter parameters: ['id', 'name', 'description',
             'type', 'subtype', 'date_created', 'date_modified', 'version',
             'acg', 'icon_path', 'owner']
@@ -34,16 +43,32 @@ def list_security_filters(connection: "Connection", to_dictionary: bool = False,
     Returns:
         list of security filter objects or list of security filter dicts.
     """
-    connection._validate_application_selected()
-    objects_ = list_objects(connection, ObjectTypes.SECURITY_FILTER, connection.application_id,
-                            limit=limit, **filters)
+    connection._validate_project_selected()
+    if user and user_group:
+        helper.exception_handler(
+            "You cannot filter by both `user` and `user_group` at the same time.")
+
+    if user:
+        user = User(connection, id=user) if isinstance(user, str) else user
+        # filter security filters by user for project specified in `connection`
+        objects_ = user.list_security_filters(connection.project_id,
+                                              to_dictionary=True).get(connection.project_name, [])
+    elif user_group:
+        user_group = UserGroup(connection, id=user_group) if isinstance(user_group,
+                                                                        str) else user_group
+        # filter security filters by the user group for project specified in
+        # `connection`
+        objects_ = user_group.list_security_filters(connection.project_id, to_dictionary=True).get(
+            connection.project_name, [])
+    else:
+        objects_ = full_search(connection, object_types=ObjectTypes.SECURITY_FILTER,
+                               project=connection.project_id, limit=limit, **filters)
     if to_dictionary:
         return objects_
-    else:
-        return [SecurityFilter.from_dict(obj_, connection) for obj_ in objects_]
+    return [SecurityFilter.from_dict(obj_, connection) for obj_ in objects_]
 
 
-class SecurityFilter(Entity):
+class SecurityFilter(Entity, DeleteMixin):
 
     _OBJECT_TYPE = ObjectTypes.SECURITY_FILTER
     _OBJECT_SUBTYPE = ObjectSubTypes.MD_SECURITY_FILTER.value
@@ -61,15 +86,15 @@ class SecurityFilter(Entity):
                 `connection.Connection()`.
             id (str): Identifier of a pre-existing security filter containing
                 the required data.
-            name (str): name of security filter.
+            name (str, optional): name of security filter.
         """
         super().__init__(connection, id, name=name)
-        connection._validate_application_selected()
+        connection._validate_project_selected()
 
     def _get_definition(self):
         """Get the definition of security filter."""
         res = security_filters.read_security_filter(
-            self.connection, self.id, self.connection.application_id,
+            self.connection, self.id, self.connection.project_id,
             show_expression_as=ShowExpressionAs.TREE.value).json()
         self._information = ObjectInformation.from_dict(res['information'])
         self._qualification = Qualification.from_dict(res['qualification'])
@@ -85,7 +110,7 @@ class SecurityFilter(Entity):
         res = security_filters.get_security_filter_members(
             self.connection,
             self.id,
-            self.connection.application_id,
+            self.connection.project_id,
         ).json()
         self._members = []
         for obj in res['users']:
@@ -280,29 +305,6 @@ class SecurityFilter(Entity):
             self.__definition_retrieved = self._information is not None and self._qualification is\
                 not None and self._top_level is not None and self._bottom_level is not None
 
-    def delete(self, force: bool = False):
-        """Delete the security filter.
-
-        Args:
-            force: If True, then no additional prompt will be shown before
-                deleting security filter.
-
-        Returns:
-            True for success. False otherwise.
-        """
-        user_input = 'N'
-        if not force:
-            user_input = input(f"Are you sure you want to delete security filter '{self.name}' "
-                               f"with ID: {self._id}? [Y/N]: ") or 'N'
-        if force or user_input == 'Y':
-            response = objects.delete_object(self._connection, self._id,
-                                             ObjectTypes.SECURITY_FILTER.value)
-            if response.status_code == 204 and config.verbose:
-                print(f"Successfully deleted security filter with ID: {self._id}.")
-            return response.ok
-        else:
-            return False
-
     @staticmethod
     def __retrieve_ids_from_list(
         objects: Union[str, "User", "UserGroup", List[Union[str, "User",
@@ -321,8 +323,8 @@ class SecurityFilter(Entity):
         users_or_groups = self.__retrieve_ids_from_list(users_and_groups)
         body = {"operationList": [{"op": op.value, "path": "/members", "value": users_or_groups}]}
         res = security_filters.update_security_filter_members(self.connection, self.id, body,
-                                                              self.connection.application_id,
-                                                              throw_err=False)
+                                                              self.connection.project_id,
+                                                              throw_error=False)
         if res.ok:
             self._get_members()
         return res.ok
