@@ -13,7 +13,7 @@ def create_changeset(connection: "Connection", project_id: str = None, schema_ed
     if project_id is None:
         connection._validate_project_selected()
         project_id = connection.project_id
-    return connection.session.post(
+    return connection.post(
         url=f"{connection.base_url}/api/model/changesets",
         headers={'X-MSTR-ProjectID': project_id},
         params={'schemaEdit': str(schema_edit).lower()}
@@ -24,7 +24,7 @@ def create_changeset(connection: "Connection", project_id: str = None, schema_ed
 def commit_changeset_changes(connection: "Connection", id: str, error_msg: str = None,
                              throw_error=True):
     """Commit the changeset changes to metadata."""
-    return connection.session.post(
+    return connection.post(
         url=f"{connection.base_url}/api/model/changesets/{id}/commit",
         headers={'X-MSTR-MSChanget': id}, params={'changesetId': id}
     )
@@ -33,7 +33,7 @@ def commit_changeset_changes(connection: "Connection", id: str, error_msg: str =
 @ErrorHandler(err_msg='Error deleting the changeset with ID {id}')
 def delete_changeset(connection: "Connection", id: str, error_msg: str = None):
     """Delete the changeset."""
-    return connection.session.delete(
+    return connection.delete(
         url=f"{connection.base_url}/api/model/changesets/{id}",
         headers={'X-MSTR-MSChanget': id},
         params={'changesetId': id}
