@@ -25,8 +25,7 @@ class Encoder(object):
 
     __b64_data = None
     __orientation = None
-    __table_type_orient_map = {"single": "records",
-                               "multi": "values"}
+    __table_type_orient_map = {"single": "records", "multi": "values"}
 
     def __init__(self, data_frame, dataset_type):
         """Inits Encoder with given data_frame and type.
@@ -40,14 +39,16 @@ class Encoder(object):
 
         # Sets the proper orientation
         if dataset_type not in self.__table_type_orient_map.keys():
-            raise ValueError("Table type should be one of " + '%s' % ', '.join(map(str, self.__table_type_orient_map)))
+            raise ValueError("Table type should be one of "
+                             + '%s' % ', '.join(map(str, self.__table_type_orient_map)))
         else:
             self.__orientation = self.__table_type_orient_map[dataset_type]
 
     @property
     def encode(self):
         """Encode data in base 64."""
-        self.__b64_data = b64encode(self.__data_frame.to_json(orient=self.__orientation,
-                                                              date_format='iso').encode('utf-8')).decode('utf-8')
+        self.__b64_data = b64encode(
+            self.__data_frame.to_json(orient=self.__orientation,
+                                      date_format='iso').encode('utf-8')).decode('utf-8')
         # return base 64 encoded data to calling environment
         return self.__b64_data
